Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(824)

Unified Diff: services/ui/ws/drag_controller_unittest.cc

Issue 2786693002: Add PointerDetails to ui::MouseEvent's constructors (Closed)
Patch Set: mouse constructor Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/ws/drag_controller_unittest.cc
diff --git a/services/ui/ws/drag_controller_unittest.cc b/services/ui/ws/drag_controller_unittest.cc
index 335264077dbcef9711bb96d7d71b59b7979cdfba..86dfb7c07cc90f44ce9a8ce9919544675a4caab7 100644
--- a/services/ui/ws/drag_controller_unittest.cc
+++ b/services/ui/ws/drag_controller_unittest.cc
@@ -155,7 +155,7 @@ class DragControllerTest : public testing::Test,
window->PerformOnDragDropStart(
std::unordered_map<std::string, std::vector<uint8_t>>());
drag_operation_ = base::MakeUnique<DragController>(
- this, this, window->window(), window, PointerEvent::kMousePointerId,
+ this, this, window->window(), window, MouseEvent::kMousePointerId,
std::unordered_map<std::string, std::vector<uint8_t>>(),
drag_operations);
@@ -627,7 +627,7 @@ TEST_F(DragControllerTest, CancelDrag) {
TEST_F(DragControllerTest, IgnoreEventsFromOtherPointers) {
std::unique_ptr<DragTestWindow> window = BuildWindow();
// This starts the operation with PointerEvent::kMousePointerId.
StartDragOperation(window.get(), ui::mojom::kDropEffectMove);
// Ignore events from pointer 5.
@@ -627,7 +627,7 @@ TEST_F(DragControllerTest, CancelDrag) {
TEST_F(DragControllerTest, IgnoreEventsFromOtherPointers) {
std::unique_ptr<DragTestWindow> window = BuildWindow();
- // This starts the operation with PointerEvent::kMousePointerId.
+ // This starts the operation with MouseEvent::kMousePointerId.
StartDragOperation(window.get(), ui::mojom::kDropEffectMove);
// Ignore events from pointer 5.

Powered by Google App Engine
This is Rietveld 408576698